defaultIdleSource function
The IdleSource the plugin uses on the host this code is running on.
Implementation
IdleSource defaultIdleSource() =>
defaultIdleSourceFor(Platform.operatingSystem);
The IdleSource the plugin uses on the host this code is running on.
IdleSource defaultIdleSource() =>
defaultIdleSourceFor(Platform.operatingSystem);