flutter_inactive_timer_ffi
library
Classes
-
FfiFlutterInactiveTimer
-
An implementation of FlutterInactiveTimerPlatform that reads the Idle
duration through
dart:ffi instead of a method channel (ADR-0004).
-
IdleSource
-
A single way of reading the Idle duration — milliseconds since the
user's last keyboard or mouse input — directly from the operating system.
-
MacOsIoKitIdleSource
-
Reads the Idle duration on macOS through IOKit — the HID system service's
HIDIdleTime property — via dart:ffi (ADR-0004).
-
UnsupportedIdleSource
-
The source used on platforms this package has no FFI binding for.
-
WindowsIdleSource
-
Reads the Idle duration on Windows from
GetLastInputInfo against
GetTickCount64, through dart:ffi (ADR-0004).